# Copyright (C) 2015  Ruby-GNOME2 Project Team
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

class TestGtkTreeStore < Test::Unit::TestCase
  include GtkTestUtils

  sub_test_case "#insert" do
    test "no values" do
      store = Gtk::TreeStore.new(String)
      iter = store.insert(nil, -1)
      iter[0] = "xxx"
      assert_equal("xxx", iter[0])
    end

    test "with values" do
      store = Gtk::TreeStore.new(String, Integer)
      iter = store.insert(nil, -1, {0 => "xxx", 1 => 29})
      assert_equal(["xxx", 29], [iter[0], iter[1]])
    end
  end
end
